You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@struts.apache.org by lu...@apache.org on 2011/12/02 17:33:45 UTC

svn commit: r1209569 [9/50] - in /struts/struts2/branches/STRUTS_3_X: apps/blank/src/main/java/example/ apps/blank/src/test/java/example/ apps/jboss-blank/src/main/java/example/ apps/jboss-blank/src/test/java/example/ apps/mailreader/src/main/java/mail...

Modified: struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/codebehind/CodebehindUnknownHandlerTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/codebehind/CodebehindUnknownHandlerTest.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/codebehind/CodebehindUnknownHandlerTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/codebehind/CodebehindUnknownHandlerTest.java Fri Dec  2 16:33:03 2011
@@ -23,12 +23,17 @@ package org.apache.struts2.codebehind;
 
 import com.mockobjects.dynamic.C;
 import com.mockobjects.dynamic.Mock;
-import com.opensymphony.xwork2.*;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.entities.ResultTypeConfig;
-import com.opensymphony.xwork2.util.XWorkTestCaseHelper;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.ResultTypeConfig;
+import org.apache.struts2.xwork2.util.XWorkTestCaseHelper;
 import org.apache.struts2.StrutsTestCase;
 import org.apache.struts2.dispatcher.ServletDispatcherResult;
+import org.apache.struts2.xwork2.ActionProxyFactory;
+import org.apache.struts2.xwork2.Result;
 
 import javax.servlet.ServletContext;
 import java.net.MalformedURLException;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/ClasspathPackageProviderTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/ClasspathPackageProviderTest.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/ClasspathPackageProviderTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/ClasspathPackageProviderTest.java Fri Dec  2 16:33:03 2011
@@ -21,11 +21,11 @@
 
 package org.apache.struts2.config;
 
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.config.entities.ResultTypeConfig;
-import com.opensymphony.xwork2.config.impl.DefaultConfiguration;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.entities.ResultTypeConfig;
+import org.apache.struts2.xwork2.config.impl.DefaultConfiguration;
 import junit.framework.TestCase;
 import org.apache.struts2.dispatcher.ServletDispatcherResult;
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/cltest/ActionImpl.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/cltest/ActionImpl.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/cltest/ActionImpl.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/cltest/ActionImpl.java Fri Dec  2 16:33:03 2011
@@ -21,7 +21,7 @@
 
 package org.apache.struts2.config.cltest;
 
-import com.opensymphony.xwork2.Action;
+import org.apache.struts2.xwork2.Action;
 
 public class ActionImpl implements Action {
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/parenttest/SomeAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/parenttest/SomeAction.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/parenttest/SomeAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/codebehind/src/test/java/org/apache/struts2/config/parenttest/SomeAction.java Fri Dec  2 16:33:03 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.config.parenttest;
 
-import com.opensymphony.xwork2.Action;
+import org.apache.struts2.xwork2.Action;
 
 public class SomeAction implements Action {
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ActionNamesAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ActionNamesAction.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ActionNamesAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ActionNamesAction.java Fri Dec  2 16:33:03 2011
@@ -21,9 +21,9 @@
 
 package org.apache.struts2.config_browser;
 
-import com.opensymphony.xwork2.ActionSupport;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.inject.Inject;
 import org.apache.struts2.StrutsConstants;
 
 import java.util.Set;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ConfigurationHelper.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ConfigurationHelper.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ConfigurationHelper.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ConfigurationHelper.java Fri Dec  2 16:33:03 2011
@@ -25,20 +25,15 @@ import java.io.IOException;
 import java.net.URL;
 import java.util.ArrayList;
 import java.util.Collections;
-import java.util.Iterator;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
 
-import org.apache.struts2.dispatcher.Dispatcher;
-import org.apache.struts2.util.ClassLoaderUtils;
-
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ClassLoaderUtil;
-import com.opensymphony.xwork2.util.ResolverUtil;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ResolverUtil;
 
 /**
  * ConfigurationHelper

Modified: struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ListValidatorsAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ListValidatorsAction.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ListValidatorsAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ListValidatorsAction.java Fri Dec  2 16:33:03 2011
@@ -21,11 +21,11 @@
 
 package org.apache.struts2.config_browser;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionSupport;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.validator.ActionValidatorManager;
-import com.opensymphony.xwork2.validator.Validator;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.validator.ActionValidatorManager;
+import org.apache.struts2.xwork2.validator.Validator;
 import org.apache.struts2.util.ClassLoaderUtils;
 
 import java.util.Collections;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowBeansAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowBeansAction.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowBeansAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowBeansAction.java Fri Dec  2 16:33:03 2011
@@ -33,13 +33,13 @@ import org.apache.struts2.dispatcher.mul
 import org.apache.struts2.views.freemarker.FreemarkerManager;
 import org.apache.struts2.views.velocity.VelocityManager;
 
-import com.opensymphony.xwork2.ActionProxyFactory;
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.TextProvider;
-import com.opensymphony.xwork2.conversion.ObjectTypeDeterminer;
-import com.opensymphony.xwork2.conversion.impl.XWorkConverter;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.ActionProxyFactory;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.TextProvider;
+import org.apache.struts2.xwork2.conversion.ObjectTypeDeterminer;
+import org.apache.struts2.xwork2.conversion.impl.XWorkConverter;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
 
 /**
  * Shows the beans loaded by the internal Guice container.  Only shows beans that are recognized by Struts as official

Modified: struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowConfigAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowConfigAction.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowConfigAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowConfigAction.java Fri Dec  2 16:33:03 2011
@@ -25,12 +25,12 @@ import java.beans.PropertyDescriptor;
 import java.util.Set;
 import java.util.TreeSet;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionProvider;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionProvider;
 
 /**
  * ShowConfigAction

Modified: struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowConstantsAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowConstantsAction.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowConstantsAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowConstantsAction.java Fri Dec  2 16:33:03 2011
@@ -24,8 +24,8 @@ package org.apache.struts2.config_browse
 import java.util.HashMap;
 import java.util.Map;
 
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
 
 /**
  * Shows all constants as loaded by Struts

Modified: struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowJarsAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowJarsAction.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowJarsAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowJarsAction.java Fri Dec  2 16:33:03 2011
@@ -24,15 +24,13 @@ package org.apache.struts2.config_browse
 import java.io.IOException;
 import java.net.URL;
 import java.util.Collections;
-import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
-import java.util.Map;
 import java.util.Properties;
 
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.ClassLoaderUtil;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.ClassLoaderUtil;
 
 /**
  * Shows all constants as loaded by Struts

Modified: struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowValidatorAction.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowValidatorAction.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowValidatorAction.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/config-browser/src/main/java/org/apache/struts2/config_browser/ShowValidatorAction.java Fri Dec  2 16:33:03 2011
@@ -30,13 +30,13 @@ import java.util.Map;
 import java.util.Set;
 import java.util.TreeSet;
 
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionContextFactory;
-import com.opensymphony.xwork2.util.reflection.ReflectionException;
-import com.opensymphony.xwork2.util.reflection.ReflectionProvider;
-import com.opensymphony.xwork2.validator.Validator;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionContextFactory;
+import org.apache.struts2.xwork2.util.reflection.ReflectionException;
+import org.apache.struts2.xwork2.util.reflection.ReflectionProvider;
+import org.apache.struts2.xwork2.validator.Validator;
 
 /**
  * ShowValidatorAction

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ClasspathConfigurationProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ClasspathConfigurationProvider.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ClasspathConfigurationProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ClasspathConfigurationProvider.java Fri Dec  2 16:33:03 2011
@@ -20,13 +20,13 @@
  */
 package org.apache.struts2.convention;
 
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.ConfigurationProvider;
-import com.opensymphony.xwork2.inject.ContainerBuilder;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.util.location.LocatableProperties;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.ConfigurationProvider;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.ContainerBuilder;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.location.LocatableProperties;
 import org.apache.struts2.dispatcher.DispatcherListener;
 import org.apache.struts2.dispatcher.Dispatcher;
 import org.apache.struts2.StrutsConstants;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ClasspathPackageProvider.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ClasspathPackageProvider.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ClasspathPackageProvider.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ClasspathPackageProvider.java Fri Dec  2 16:33:03 2011
@@ -19,11 +19,11 @@
  * under the License.
  */package org.apache.struts2.convention;
 
-import com.opensymphony.xwork2.config.PackageProvider;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.inject.Container;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.PackageProvider;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
 
 /**
  * <p>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ConventionUnknownHandler.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ConventionUnknownHandler.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ConventionUnknownHandler.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ConventionUnknownHandler.java Fri Dec  2 16:33:03 2011
@@ -25,23 +25,27 @@ import java.util.*;
 
 import javax.servlet.ServletContext;
 
-import com.opensymphony.xwork2.config.entities.*;
-import com.opensymphony.xwork2.config.providers.InterceptorBuilder;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.Result;
+import org.apache.struts2.xwork2.UnknownHandler;
+import org.apache.struts2.xwork2.XWorkException;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.config.entities.ResultTypeConfig;
+import org.apache.struts2.xwork2.config.providers.InterceptorBuilder;
 import org.apache.struts2.util.ClassLoaderUtils;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ActionSupport;
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.Result;
-import com.opensymphony.xwork2.UnknownHandler;
-import com.opensymphony.xwork2.XWorkException;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.config.entities.InterceptorMapping;
 
 /**
  * <p>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ConventionsService.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ConventionsService.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ConventionsService.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ConventionsService.java Fri Dec  2 16:33:03 2011
@@ -22,9 +22,9 @@ package org.apache.struts2.convention;
 
 import java.util.Map;
 
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.config.entities.ResultTypeConfig;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.entities.ResultTypeConfig;
 
 /**
  * <p>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ConventionsServiceImpl.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ConventionsServiceImpl.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ConventionsServiceImpl.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ConventionsServiceImpl.java Fri Dec  2 16:33:03 2011
@@ -28,11 +28,11 @@ import org.apache.struts2.convention.ann
 import org.apache.struts2.convention.annotation.ResultPath;
 import org.apache.struts2.util.ClassLoaderUtils;
 
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.config.entities.ResultTypeConfig;
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.entities.ResultTypeConfig;
+import org.apache.struts2.xwork2.inject.Inject;
 
 /**
  * <p>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/DefaultActionNameBuilder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/DefaultActionNameBuilder.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/DefaultActionNameBuilder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/DefaultActionNameBuilder.java Fri Dec  2 16:33:03 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention;
 
-import com.opensymphony.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.inject.Inject;
 import org.apache.commons.lang.StringUtils;
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/DefaultInterceptorMapBuilder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/DefaultInterceptorMapBuilder.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/DefaultInterceptorMapBuilder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/DefaultInterceptorMapBuilder.java Fri Dec  2 16:33:03 2011
@@ -21,7 +21,6 @@
 package org.apache.struts2.convention;
 
 import java.util.ArrayList;
-import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 
@@ -30,16 +29,14 @@ import org.apache.struts2.convention.ann
 import org.apache.struts2.convention.annotation.InterceptorRef;
 import org.apache.struts2.convention.annotation.InterceptorRefs;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.entities.InterceptorMapping;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.config.providers.InterceptorBuilder;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.AnnotationUtils;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.entities.InterceptorMapping;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.providers.InterceptorBuilder;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <p>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/DefaultResultMapBuilder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/DefaultResultMapBuilder.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/DefaultResultMapBuilder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/DefaultResultMapBuilder.java Fri Dec  2 16:33:03 2011
@@ -35,20 +35,20 @@ import org.apache.commons.lang.StringUti
 import org.apache.struts2.convention.annotation.Result;
 import org.apache.struts2.convention.annotation.Results;
 
-import com.opensymphony.xwork2.Action;
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
-import com.opensymphony.xwork2.config.entities.ResultTypeConfig;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.finder.ClassLoaderInterface;
-import com.opensymphony.xwork2.util.finder.ClassLoaderInterfaceDelegate;
-import com.opensymphony.xwork2.util.finder.ResourceFinder;
-import com.opensymphony.xwork2.util.finder.Test;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.Action;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.config.entities.ResultTypeConfig;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.finder.ClassLoaderInterface;
+import org.apache.struts2.xwork2.util.finder.ClassLoaderInterfaceDelegate;
+import org.apache.struts2.xwork2.util.finder.ResourceFinder;
+import org.apache.struts2.xwork2.util.finder.Test;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <p>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/InterceptorMapBuilder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/InterceptorMapBuilder.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/InterceptorMapBuilder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/InterceptorMapBuilder.java Fri Dec  2 16:33:03 2011
@@ -24,8 +24,8 @@ import java.util.List;
 
 import org.apache.struts2.convention.annotation.Action;
 
-import com.opensymphony.xwork2.config.entities.InterceptorMapping;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.entities.InterceptorMapping;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
 
 /**
  * <p>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/PackageBasedActionConfigBuilder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/PackageBasedActionConfigBuilder.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ResultMapBuilder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ResultMapBuilder.java Fri Dec  2 16:33:03 2011
@@ -24,8 +24,8 @@ import java.util.Map;
 
 import org.apache.struts2.convention.annotation.Action;
 
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
 
 /**
  * <p>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/SEOActionNameBuilder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/SEOActionNameBuilder.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/SEOActionNameBuilder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/SEOActionNameBuilder.java Fri Dec  2 16:33:03 2011
@@ -20,9 +20,9 @@
  */
 package org.apache.struts2.convention;
 
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.lang.StringUtils;
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/StringTools.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/StringTools.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/StringTools.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/StringTools.java Fri Dec  2 16:33:03 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention;
 
-import com.opensymphony.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.ConfigurationException;
 
 import java.util.HashMap;
 import java.util.Map;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/annotation/Result.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/annotation/Result.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/annotation/Result.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/annotation/Result.java Fri Dec  2 16:33:03 2011
@@ -69,7 +69,7 @@ public @interface Result {
      * @return  The name of the result mapping. This is the value that is returned from the action
      *          method and is used to associate a location with a return value.
      */
-    String name() default com.opensymphony.xwork2.Action.SUCCESS;
+    String name() default org.apache.struts2.xwork2.Action.SUCCESS;
 
     /**
      * @return  The location of the result within the web application or anywhere on disk. This location

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/resources/struts-plugin.xml
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/resources/struts-plugin.xml?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/resources/struts-plugin.xml (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/resources/struts-plugin.xml Fri Dec  2 16:33:03 2011
@@ -27,7 +27,7 @@
     "http://struts.apache.org/dtds/struts-2.1.7.dtd">
 
 <struts order="20">
-  <bean type="com.opensymphony.xwork2.UnknownHandler" name="convention" class="org.apache.struts2.convention.ConventionUnknownHandler"/>
+  <bean type="org.apache.struts2.xwork2.UnknownHandler" name="convention" class="org.apache.struts2.convention.ConventionUnknownHandler"/>
 
   <bean type="org.apache.struts2.convention.ActionConfigBuilder" name="convention" class="org.apache.struts2.convention.PackageBasedActionConfigBuilder"/>
   <bean type="org.apache.struts2.convention.ActionNameBuilder" name="convention" class="org.apache.struts2.convention.SEOActionNameBuilder"/>
@@ -35,8 +35,8 @@
   <bean type="org.apache.struts2.convention.InterceptorMapBuilder" name="convention" class="org.apache.struts2.convention.DefaultInterceptorMapBuilder"/>
   <bean type="org.apache.struts2.convention.ConventionsService" name="convention" class="org.apache.struts2.convention.ConventionsServiceImpl"/>
 
-  <bean type="com.opensymphony.xwork2.config.PackageProvider" name="convention.packageProvider" class="org.apache.struts2.convention.ClasspathPackageProvider"/>
-  <bean type="com.opensymphony.xwork2.config.PackageProvider" name="convention.containerProvider" class="org.apache.struts2.convention.ClasspathConfigurationProvider"/>
+  <bean type="org.apache.struts2.xwork2.config.PackageProvider" name="convention.packageProvider" class="org.apache.struts2.convention.ClasspathPackageProvider"/>
+  <bean type="org.apache.struts2.xwork2.config.PackageProvider" name="convention.containerProvider" class="org.apache.struts2.convention.ClasspathConfigurationProvider"/>
 
   <constant name="struts.convention.actionConfigBuilder" value="convention"/>
   <constant name="struts.convention.actionNameBuilder" value="convention"/>

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/ConventionUnknownHandlerTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/ConventionUnknownHandlerTest.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/ConventionUnknownHandlerTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/ConventionUnknownHandlerTest.java Fri Dec  2 16:33:03 2011
@@ -20,11 +20,12 @@
  */
 package org.apache.struts2.convention;
 
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.config.entities.ResultTypeConfig;
-import com.opensymphony.xwork2.inject.Container;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.entities.ResultTypeConfig;
+import org.apache.struts2.xwork2.inject.Container;
 import junit.framework.TestCase;
+
 import static org.easymock.EasyMock.expect;
 import static org.easymock.classextension.EasyMock.createMock;
 import static org.easymock.classextension.EasyMock.createNiceMock;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/DefaultResultMapBuilderTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/DefaultResultMapBuilderTest.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/DefaultResultMapBuilderTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/DefaultResultMapBuilderTest.java Fri Dec  2 16:33:03 2011
@@ -39,14 +39,13 @@ import org.apache.struts2.convention.act
 import org.apache.struts2.convention.actions.result.OverrideInheritedResultExtends;
 import org.apache.struts2.convention.actions.resultpath.ClassLevelResultPathAction;
 import org.apache.struts2.convention.annotation.Action;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.config.entities.ResultTypeConfig;
+import org.apache.struts2.xwork2.inject.Container;
 import org.easymock.EasyMock;
 import org.easymock.IAnswer;
 
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
-import com.opensymphony.xwork2.config.entities.ResultTypeConfig;
-import com.opensymphony.xwork2.inject.Container;
-
 /**
  * <p>
  * This class tests the simple result map builder.

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/PackageBasedActionConfigBuilderTest.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/PackageBasedActionConfigBuilderTest.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/PackageBasedActionConfigBuilderTest.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/PackageBasedActionConfigBuilderTest.java Fri Dec  2 16:33:03 2011
@@ -66,26 +66,26 @@ import org.apache.struts2.convention.act
 import org.apache.struts2.convention.annotation.Action;
 import org.apache.struts2.convention.annotation.Actions;
 import org.apache.struts2.dispatcher.ServletDispatcherResult;
+import org.apache.struts2.xwork2.ActionChainResult;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.Result;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.ExceptionMappingConfig;
+import org.apache.struts2.xwork2.config.entities.InterceptorConfig;
+import org.apache.struts2.xwork2.config.entities.InterceptorMapping;
+import org.apache.struts2.xwork2.config.entities.InterceptorStackConfig;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.config.entities.ResultTypeConfig;
+import org.apache.struts2.xwork2.config.impl.DefaultConfiguration;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.ognl.OgnlReflectionProvider;
+import org.apache.struts2.xwork2.util.reflection.ReflectionException;
 import org.easymock.EasyMock;
 
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.Result;
-import com.opensymphony.xwork2.ActionChainResult;
-import com.opensymphony.xwork2.util.reflection.ReflectionException;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.entities.ExceptionMappingConfig;
-import com.opensymphony.xwork2.config.entities.InterceptorConfig;
-import com.opensymphony.xwork2.config.entities.InterceptorMapping;
-import com.opensymphony.xwork2.config.entities.InterceptorStackConfig;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
-import com.opensymphony.xwork2.config.entities.ResultTypeConfig;
-import com.opensymphony.xwork2.config.impl.DefaultConfiguration;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Scope.Strategy;
-import com.opensymphony.xwork2.ognl.OgnlReflectionProvider;
+import org.apache.struts2.xwork2.inject.Scope.Strategy;
 
 import javax.servlet.ServletContext;
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/TestInterceptor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/TestInterceptor.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/TestInterceptor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/TestInterceptor.java Fri Dec  2 16:33:03 2011
@@ -1,7 +1,7 @@
 package org.apache.struts2.convention;
 
-import com.opensymphony.xwork2.ActionInvocation;
-import com.opensymphony.xwork2.interceptor.AbstractInterceptor;
+import org.apache.struts2.xwork2.ActionInvocation;
+import org.apache.struts2.xwork2.interceptor.AbstractInterceptor;
 
 public class TestInterceptor extends AbstractInterceptor {
 	private String string1;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/Skip.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/Skip.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/Skip.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/Skip.java Fri Dec  2 16:33:03 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention.actions;
 
-import com.opensymphony.xwork2.Action;
+import org.apache.struts2.xwork2.Action;
 
 public class Skip implements Action {
     public String execute() throws Exception {

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/action/TestBase.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/action/TestBase.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/action/TestBase.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/action/TestBase.java Fri Dec  2 16:33:03 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention.actions.action;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 
 public abstract class TestBase extends ActionSupport {
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/defaultinterceptor/SingleActionNameAction2.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/defaultinterceptor/SingleActionNameAction2.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/defaultinterceptor/SingleActionNameAction2.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/defaultinterceptor/SingleActionNameAction2.java Fri Dec  2 16:33:03 2011
@@ -27,7 +27,7 @@ import org.apache.struts2.convention.ann
  * This is a test action.
  * </p>
  */
-public class SingleActionNameAction2 implements com.opensymphony.xwork2.Action{
+public class SingleActionNameAction2 implements org.apache.struts2.xwork2.Action {
     @Action("action345")
     public String execute() {
         return null;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/Index.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/Index.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/Index.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/Index.java Fri Dec  2 16:33:03 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention.actions.idx;
 
-import com.opensymphony.xwork2.Action;
+import org.apache.struts2.xwork2.Action;
 
 public class Index implements Action {
     public String execute() throws Exception {

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/idx2/Index.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/idx2/Index.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/idx2/Index.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/idx/idx2/Index.java Fri Dec  2 16:33:03 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention.actions.idx.idx2;
 
-import com.opensymphony.xwork2.Action;
+import org.apache.struts2.xwork2.Action;
 
 public class Index implements Action {
     public String execute() throws Exception {

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/result/InheritedResultTestBase.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/result/InheritedResultTestBase.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/result/InheritedResultTestBase.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/result/InheritedResultTestBase.java Fri Dec  2 16:33:03 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention.actions.result;
 
-import com.opensymphony.xwork2.ActionSupport;
+import org.apache.struts2.xwork2.ActionSupport;
 import org.apache.struts2.convention.annotation.Result;
 
 @Result(name="error", location="error.jsp", params={"key", "value", "key1", "value1"})

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/skip/Index.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/skip/Index.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/skip/Index.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/test/java/org/apache/struts2/convention/actions/skip/Index.java Fri Dec  2 16:33:03 2011
@@ -20,7 +20,7 @@
  */
 package org.apache.struts2.convention.actions.skip;
 
-import com.opensymphony.xwork2.Action;
+import org.apache.struts2.xwork2.Action;
 
 public class Index implements Action {
     public String execute() throws Exception {

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractRemoteBean.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractRemoteBean.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractRemoteBean.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractRemoteBean.java Fri Dec  2 16:33:03 2011
@@ -30,7 +30,7 @@ import org.apache.struts2.components.Clo
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * AbstractRemoteCallUIBean is superclass for all components dealing with remote

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractValidateBean.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractValidateBean.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractValidateBean.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/AbstractValidateBean.java Fri Dec  2 16:33:03 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Form;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * Base class for tags that perform AJAX validation

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Anchor.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Anchor.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Anchor.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Anchor.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Autocompleter.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Autocompleter.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Autocompleter.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Autocompleter.java Fri Dec  2 16:33:03 2011
@@ -31,7 +31,7 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Bind.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Bind.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Bind.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Bind.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/DateTimePicker.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/DateTimePicker.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/DateTimePicker.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/DateTimePicker.java Fri Dec  2 16:33:03 2011
@@ -22,7 +22,6 @@
 package org.apache.struts2.dojo.components;
 
 import java.text.DateFormat;
-import java.text.Format;
 import java.text.MessageFormat;
 import java.text.SimpleDateFormat;
 import java.util.ArrayList;
@@ -39,9 +38,9 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Div.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Div.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Div.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Div.java Fri Dec  2 16:33:03 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Head.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Head.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Head.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Head.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: notice -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Submit.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Submit.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Submit.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Submit.java Fri Dec  2 16:33:03 2011
@@ -33,9 +33,9 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import com.opensymphony.xwork2.util.ValueStack;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TabbedPanel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TabbedPanel.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TabbedPanel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TabbedPanel.java Fri Dec  2 16:33:03 2011
@@ -21,7 +21,7 @@
 
 package org.apache.struts2.dojo.components;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 import org.apache.struts2.components.ClosingUIBean;
 import org.apache.struts2.views.annotations.StrutsTag;
 import org.apache.struts2.views.annotations.StrutsTagAttribute;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TextArea.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TextArea.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TextArea.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TextArea.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import javax.servlet.http.HttpServletRes
 
 import org.apache.struts2.views.annotations.StrutsTag;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Tree.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Tree.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Tree.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/Tree.java Fri Dec  2 16:33:03 2011
@@ -34,7 +34,7 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TreeNode.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TreeNode.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TreeNode.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/components/TreeNode.java Fri Dec  2 16:33:03 2011
@@ -31,7 +31,7 @@ import org.apache.struts2.views.annotati
 import org.apache.struts2.views.annotations.StrutsTagAttribute;
 import org.apache.struts2.views.annotations.StrutsTagSkipInheritance;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * <!-- START SNIPPET: javadoc -->

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/DojoTagLibrary.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/DojoTagLibrary.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/DojoTagLibrary.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/DojoTagLibrary.java Fri Dec  2 16:33:03 2011
@@ -41,7 +41,7 @@ import org.apache.struts2.dojo.views.vel
 import org.apache.struts2.dojo.views.velocity.components.TreeNodeDirective;
 import org.apache.struts2.views.TagLibrary;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 public class DojoTagLibrary implements TagLibrary {
 

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AnchorModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AnchorModel.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AnchorModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AnchorModel.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Anchor;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see Anchor

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AutocompleterModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AutocompleterModel.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AutocompleterModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/AutocompleterModel.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Autocompleter;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see Autocompleter

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/BindModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/BindModel.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/BindModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/BindModel.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Bind;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see Bind

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DateTimePickerModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DateTimePickerModel.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DateTimePickerModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DateTimePickerModel.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.DateTimePicker;
 import org.apache.struts2.views.freemarker.tags.TextFieldModel;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see DropdownDateTimePicker

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DivModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DivModel.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DivModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DivModel.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Div;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 
 /**

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DojoModels.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DojoModels.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DojoModels.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/DojoModels.java Fri Dec  2 16:33:03 2011
@@ -24,7 +24,7 @@ package org.apache.struts2.dojo.views.fr
 import javax.servlet.http.HttpServletRequest;
 import javax.servlet.http.HttpServletResponse;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 public class DojoModels {
     protected DateTimePickerModel dateTimePicker;

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/HeadModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/HeadModel.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/HeadModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/HeadModel.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Head;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see Head

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/SubmitModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/SubmitModel.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/SubmitModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/SubmitModel.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Submit;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see Submit

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TabbedPanelModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TabbedPanelModel.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TabbedPanelModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TabbedPanelModel.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.TabbedPanel;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see TabbedPanel

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TextAreaModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TextAreaModel.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TextAreaModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TextAreaModel.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.TextArea;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see TextArea

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeModel.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeModel.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Tree;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * TreeModel

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeNodeModel.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeNodeModel.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeNodeModel.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/freemarker/tags/TreeNodeModel.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.TreeNode;
 import org.apache.struts2.views.freemarker.tags.TagModel;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * TreeNodeModel

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AnchorTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AnchorTag.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AnchorTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AnchorTag.java Fri Dec  2 16:33:03 2011
@@ -27,7 +27,7 @@ import javax.servlet.http.HttpServletRes
 import org.apache.struts2.components.Component;
 import org.apache.struts2.dojo.components.Anchor;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see Anchor

Modified: struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AutocompleterTag.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AutocompleterTag.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================
--- struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AutocompleterTag.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/dojo/src/main/java/org/apache/struts2/dojo/views/jsp/ui/AutocompleterTag.java Fri Dec  2 16:33:03 2011
@@ -28,7 +28,7 @@ import org.apache.struts2.components.Com
 import org.apache.struts2.dojo.components.Autocompleter;
 import org.apache.struts2.views.jsp.ui.ComboBoxTag;
 
-import com.opensymphony.xwork2.util.ValueStack;
+import org.apache.struts2.xwork2.util.ValueStack;
 
 /**
  * @see Autocompleter
--- struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/PackageBasedActionConfigBuilder.java (original)
+++ struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/PackageBasedActionConfigBuilder.java Fri Dec  2 16:33:03 2011
@@ -20,28 +20,28 @@
  */
 package org.apache.struts2.convention;
 
-import com.opensymphony.xwork2.ActionContext;
-import com.opensymphony.xwork2.ObjectFactory;
-import com.opensymphony.xwork2.config.Configuration;
-import com.opensymphony.xwork2.config.ConfigurationException;
-import com.opensymphony.xwork2.config.entities.ActionConfig;
-import com.opensymphony.xwork2.config.entities.ExceptionMappingConfig;
-import com.opensymphony.xwork2.config.entities.InterceptorMapping;
-import com.opensymphony.xwork2.config.entities.PackageConfig;
-import com.opensymphony.xwork2.config.entities.ResultConfig;
-import com.opensymphony.xwork2.inject.Container;
-import com.opensymphony.xwork2.inject.Inject;
-import com.opensymphony.xwork2.util.FileManager;
-import com.opensymphony.xwork2.util.TextParseUtil;
-import com.opensymphony.xwork2.util.classloader.ReloadingClassLoader;
-import com.opensymphony.xwork2.util.finder.ClassFinder;
-import com.opensymphony.xwork2.util.finder.ClassFinder.ClassInfo;
-import com.opensymphony.xwork2.util.finder.ClassLoaderInterface;
-import com.opensymphony.xwork2.util.finder.ClassLoaderInterfaceDelegate;
-import com.opensymphony.xwork2.util.finder.Test;
-import com.opensymphony.xwork2.util.finder.UrlSet;
-import com.opensymphony.xwork2.util.logging.Logger;
-import com.opensymphony.xwork2.util.logging.LoggerFactory;
+import org.apache.struts2.xwork2.ActionContext;
+import org.apache.struts2.xwork2.ObjectFactory;
+import org.apache.struts2.xwork2.config.Configuration;
+import org.apache.struts2.xwork2.config.ConfigurationException;
+import org.apache.struts2.xwork2.config.entities.ActionConfig;
+import org.apache.struts2.xwork2.config.entities.ExceptionMappingConfig;
+import org.apache.struts2.xwork2.config.entities.InterceptorMapping;
+import org.apache.struts2.xwork2.config.entities.PackageConfig;
+import org.apache.struts2.xwork2.config.entities.ResultConfig;
+import org.apache.struts2.xwork2.inject.Container;
+import org.apache.struts2.xwork2.inject.Inject;
+import org.apache.struts2.xwork2.util.FileManager;
+import org.apache.struts2.xwork2.util.TextParseUtil;
+import org.apache.struts2.xwork2.util.classloader.ReloadingClassLoader;
+import org.apache.struts2.xwork2.util.finder.ClassFinder;
+import org.apache.struts2.xwork2.util.finder.ClassFinder.ClassInfo;
+import org.apache.struts2.xwork2.util.finder.ClassLoaderInterface;
+import org.apache.struts2.xwork2.util.finder.ClassLoaderInterfaceDelegate;
+import org.apache.struts2.xwork2.util.finder.Test;
+import org.apache.struts2.xwork2.util.finder.UrlSet;
+import org.apache.struts2.xwork2.util.logging.Logger;
+import org.apache.struts2.xwork2.util.logging.LoggerFactory;
 import org.apache.commons.lang.ObjectUtils;
 import org.apache.commons.lang.StringUtils;
 import org.apache.struts2.StrutsConstants;
@@ -224,7 +224,7 @@ public class PackageBasedActionConfigBui
     }
 
     /**
      * @param checkImplementsAction (Optional) Map classes that implement com.opensymphony.xwork2.Action
      *                       as actions
      */
     @Inject(value = "struts.convention.action.checkImplementsAction", required = false)
@@ -470,7 +470,7 @@ public class PackageBasedActionConfigBui
     /**
      * Note that we can't include the test for {@link #actionSuffix} here
      * because a class is included if its name ends in {@link #actionSuffix} OR
      * it implements {@link com.opensymphony.xwork2.Action}. Since the whole
      * goal is to avoid loading the class if we don't have to, the (actionSuffix
      * || implements Action) test will have to remain until later. See
      * {@link #getActionClassTest()} for the test performed on the loaded
@@ -510,13 +510,13 @@ public class PackageBasedActionConfigBui
     }
     
     /**
      * Construct a {@link Test} object that determines if a specified class name
      * should be included in the package scan based on the clazz's package name.
      * Note that the goal is to avoid loading the class, so the test should only
      * rely on information in the class name itself. The default implementation
      * is to return the result of {@link #includeClassNameInActionScan(String)}.
      * 
-     * @return a {@link Test} object that returns true if the specified class
+     * @return a {@link org.apache.struts2.xwork2.util.finder.Test} object that returns true if the specified class
      *         name should be included in the package scan
      */
     protected Test<String> getClassPackageTest() {
@@ -528,13 +528,13 @@ public class PackageBasedActionConfigBui
     }
 
     /**
      * Construct a {@link Test} Object that determines if a specified class
      * should be included in the package scan based on the full {@link ClassInfo}
      * of the class. At this point, the class has been loaded, so it's ok to
      * perform tests such as checking annotations or looking at interfaces or
      * super-classes of the specified class.
      * 
-     * @return a {@link Test} object that returns true if the specified class
+     * @return a {@link org.apache.struts2.xwork2.util.finder.Test} object that returns true if the specified class
      *         should be included in the package scan
      */
     protected Test<ClassFinder.ClassInfo> getActionClassTest() {
@@ -545,13 +545,13 @@ public class PackageBasedActionConfigBui
                 // already been called to in the initial call to ClassFinder?
                 // When some action class passes our package filter in that step,
                 // ClassFinder automatically includes parent classes of that action,
                 // such as com.opensymphony.xwork2.ActionSupport.  We repeat the
                 // package filter here to filter out such results.
                 boolean inPackage = includeClassNameInActionScan(classInfo.getName());
                 boolean nameMatches = classInfo.getName().endsWith(actionSuffix);
 
                 try {
-                    return inPackage && (nameMatches || (checkImplementsAction && com.opensymphony.xwork2.Action.class.isAssignableFrom(classInfo.get())));
+                    return inPackage && (nameMatches || (checkImplementsAction && org.apache.struts2.xwork2.Action.class.isAssignableFrom(classInfo.get())));
                 } catch (ClassNotFoundException ex) {
                     if (LOG.isErrorEnabled())
                         LOG.error("Unable to load class [#0]", ex, classInfo.getName());
@@ -224,7 +224,7 @@ public class PackageBasedActionConfigBui
 
     /**
-     * @param checkImplementsAction (Optional) Map classes that implement com.opensymphony.xwork2.Action
+     * @param checkImplementsAction (Optional) Map classes that implement org.apache.struts2.xwork2.Action
      *                       as actions
      */
@@ -470,7 +470,7 @@ public class PackageBasedActionConfigBui
      * Note that we can't include the test for {@link #actionSuffix} here
      * because a class is included if its name ends in {@link #actionSuffix} OR
-     * it implements {@link com.opensymphony.xwork2.Action}. Since the whole
+     * it implements {@link org.apache.struts2.xwork2.Action}. Since the whole
      * goal is to avoid loading the class if we don't have to, the (actionSuffix
      * || implements Action) test will have to remain until later. See
@@ -510,13 +510,13 @@ public class PackageBasedActionConfigBui
     
     /**
-     * Construct a {@link Test} object that determines if a specified class name
+     * Construct a {@link org.apache.struts2.xwork2.util.finder.Test} object that determines if a specified class name
      * should be included in the package scan based on the clazz's package name.
      * Note that the goal is to avoid loading the class, so the test should only
@@ -528,13 +528,13 @@ public class PackageBasedActionConfigBui
 
     /**
-     * Construct a {@link Test} Object that determines if a specified class
+     * Construct a {@link org.apache.struts2.xwork2.util.finder.Test} Object that determines if a specified class
      * should be included in the package scan based on the full {@link ClassInfo}
      * of the class. At this point, the class has been loaded, so it's ok to
@@ -545,13 +545,13 @@ public class PackageBasedActionConfigBui
                 // When some action class passes our package filter in that step,
                 // ClassFinder automatically includes parent classes of that action,
-                // such as com.opensymphony.xwork2.ActionSupport.  We repeat the
+                // such as org.apache.struts2.xwork2.ActionSupport.  We repeat the
                 // package filter here to filter out such results.
                 boolean inPackage = includeClassNameInActionScan(classInfo.getName());

Modified: struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ResultMapBuilder.java
URL: http://svn.apache.org/viewvc/struts/struts2/branches/STRUTS_3_X/plugins/convention/src/main/java/org/apache/struts2/convention/ResultMapBuilder.java?rev=1209569&r1=1209568&r2=1209569&view=diff
==============================================================================